@@ -1,7 +1,7 @@
 import logging
 
 from arpakitlib.ar_json_util import transfer_data_to_json_str
-from project.core.util import setup_logging
+from project.core.setup_logging import setup_logging
 from project.sqlalchemy_db_.sqlalchemy_db import get_cached_sqlalchemy_db
 
 _logger = logging.getLogger()
